(define-module (ui net-bridge ajax)
	:use-module (alterator str)
	:use-module (alterator ajax)
	:use-module (alterator woo)
	:use-module (alterator algo)
	:export (init))

(define *iface* (make-cell ""))

(define (ui-update-lists bridge)
  (catch/message
	(lambda()
	  (form-update-enum "bridge_members" (woo-list "/net-bridge/bridge_members" 'bridge bridge))
	  (form-update-enum "avail_ifaces" (woo-list "/net-bridge/avail_ifaces")))))

(define (init-bridge-name)
  (let ((fname (form-value "iface")))
	(if (or (not fname)
			(empty-string? fname))
	  (woo-get-option (woo-read-first "/net-bridge/new_name") 'new_name)
	  fname)))

(define (ui-init bridge)
  (cell-set! *iface* bridge)
  (form-update-value "iface" bridge)
  (form-update-enum "bridge_type" (woo-list "/net-bridge/avail_bridge_types_with_description"))
  (ui-update-lists bridge))

(define (add-iface)
  (let* ((bridge (form-value "bridge_name"))
		(name (or (form-value "avail_ifaces") "")))
	(catch/message
	  (lambda()
		(woo-write "/net-bridge/add_iface" 'language (form-value "language") 'bridge bridge 'name name)))
	(ui-update-lists bridge)))

(define (del-iface)
  (let ((bridge (form-value "bridge_name"))
		(name (or (form-value "bridge_members") "")))
	(catch/message
	  (lambda()
		(woo-write "/net-bridge/del_iface" 'language (form-value "language") 'bridge bridge 'name name)))
	(ui-update-lists bridge)))

;; NOTE need to save and restore iface to bridge_name because in list of form
;; values iface stores twice: with true iface value and "". It results to
;; concatenation of two values via ";" and iface starst with ";".
(define (ui-exit)
  (form-update-value "iface" (form-value "bridge_name"))
  (let ((bridge (form-value "bridge_name"))
        (bridge_type (form-value "bridge_type")))
    (catch/message
      (lambda()
        (woo-write "/net-bridge/set_type" 'bridge bridge 'type bridge_type))))
  (form-replace (format #f "/net-eth?iface=~A" (cell-ref *iface*))))

(define (init)
  (ui-init (init-bridge-name))
  (form-update-value "bridge_name" (form-value "iface"))
  (form-update-value "bridge_type"
                     (woo-get-option (woo-read-first "/net-bridge/type" 'name (form-value "iface")) 'type))
  (form-bind "add_iface_btn" "click" add-iface)
  (form-bind "del_iface_btn" "click" del-iface)
  (form-bind "ok" "click" ui-exit))
