(document:surround "/std/frame")

(define *name* (global 'name))

;;; UI

(hbox align "left"
      (label text (bold (_ "Bridge interface:")))
      (edit name "iface")
      (label text (bold (_ "Bridge type:")))
      (combobox name "bridge_type" enumref "/net-bridge/avail_bridge_types_with_description"))
(button (_ "Ok") name "ok")
(separator)
(gridbox columns "45;10;45"
	  (label text (_ "Members"))
	  (spacer)
	  (label text (_ "Available interfaces"))
  (listbox name "bridge_members")
  (gridbox columns "100"
	(spacer)
	(button text (_ "<<") (when clicked (add-iface)))
	(button text (_ ">>") (when clicked (del-iface)))
	(spacer))
  (listbox name "avail_ifaces")
)

;;; Functions

(define (ui-update-lists bridge)
  (catch/message
	(lambda()
	  (form-update-enum "bridge_members" (woo-list "/net-bridge/bridge_members" 'bridge bridge))
	  (form-update-enum "avail_ifaces" (woo-list "/net-bridge/avail_ifaces")))))

(define (init-bridge-name fname)
  (if (or (not fname)
		  (empty-string? fname))
	(woo-get-option (woo-read-first "/net-bridge/new_name") 'new_name)
	fname))

(define (ui-read bridge)
  (form-update-value "iface" bridge)
  (ui-update-lists bridge))

(define (add-iface)
  (let* ((bridge (form-value "iface"))
		(name (or (form-value "avail_ifaces") "")))
	(catch/message
	  (lambda()
		(woo-write "/net-bridge/add_iface" 'language (form-value "language") 'bridge bridge 'name name)))
	(ui-update-lists bridge)))


(define (del-iface)
  (let ((bridge (form-value "iface"))
		(name (or (form-value "bridge_members") "")))
	(catch/message
	  (lambda()
		(woo-write "/net-bridge/del_iface" 'language (form-value "language") 'bridge bridge 'name name)))
	(ui-update-lists bridge)))


(define (ui-init name)
  (ui-read (init-bridge-name name)))

(define (ui-exit)
  (let ((bridge (form-value "iface"))
        (bridge_type (form-value "bridge_type")))
    (catch/message
      (lambda()
        (woo-write "/net-bridge/set_type" 'bridge bridge 'type bridge_type))))
  (document:end))

;;
(document:root
  (when loaded
  (form-update-value "bridge_type"
                     (woo-get-option (woo-read-first "/net-bridge/type" 'name *name*) 'type))
  (ui-init *name*)
  (form-bind "ok" "click" ui-exit)))
